Class: Aws::SimSpaceWeaver::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::SimSpaceWeaver::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-simspaceweaver/client.rb,
sig/client.rbs
Overview
An API client for SimSpaceWeaver. To construct a client, you need to configure a :region and :credentials.
client = Aws::SimSpaceWeaver::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CreateSnapshotResponseSuccess, _DeleteAppResponseSuccess, _DeleteSimulationResponseSuccess, _DescribeAppResponseSuccess, _DescribeSimulationResponseSuccess, _ListAppsResponseSuccess, _ListSimulationsResponseSuccess, _ListTagsForResourceResponseSuccess, _StartAppResponseSuccess, _StartClockResponseSuccess, _StartSimulationResponseSuccess, _StopAppResponseSuccess, _StopClockResponseSuccess, _StopSimulationResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_snapshot(params = {}) ⇒ Struct
Creates a snapshot of the specified simulation.
-
#delete_app(params = {}) ⇒ Struct
Deletes the instance of the given custom app.
-
#delete_simulation(params = {}) ⇒ Struct
Deletes all SimSpace Weaver resources assigned to the given simulation.
-
#describe_app(params = {}) ⇒ Types::DescribeAppOutput
Returns the state of the given custom app.
-
#describe_simulation(params = {}) ⇒ Types::DescribeSimulationOutput
Returns the current state of the given simulation.
-
#list_apps(params = {}) ⇒ Types::ListAppsOutput
Lists all custom apps or service apps for the given simulation and domain.
-
#list_simulations(params = {}) ⇒ Types::ListSimulationsOutput
Lists the SimSpace Weaver simulations in the Amazon Web Services account used to make the API call.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Lists all tags on a SimSpace Weaver resource.
-
#start_app(params = {}) ⇒ Types::StartAppOutput
Starts a custom app with the configuration specified in the simulation schema.
-
#start_clock(params = {}) ⇒ Struct
Starts the simulation clock.
-
#start_simulation(params = {}) ⇒ Types::StartSimulationOutput
Starts a simulation with the given name.
-
#stop_app(params = {}) ⇒ Struct
Stops the given custom app and shuts down all of its allocated compute resources.
-
#stop_clock(params = {}) ⇒ Struct
Stops the simulation clock.
-
#stop_simulation(params = {}) ⇒ Struct
Stops the given simulation.
-
#tag_resource(params = {}) ⇒ Struct
Adds tags to a SimSpace Weaver resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from a SimSpace Weaver resource.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-simspaceweaver/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1259 1260 1261 |
# File 'lib/aws-sdk-simspaceweaver/client.rb', line 1259 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1262 1263 1264 |
# File 'lib/aws-sdk-simspaceweaver/client.rb', line 1262 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1232 1233 1234 1235 1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 1247 1248 |
# File 'lib/aws-sdk-simspaceweaver/client.rb', line 1232 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::SimSpaceWeaver') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-simspaceweaver' context[:gem_version] = '1.49.0' Seahorse::Client::Request.new(handlers, context) end |
#create_snapshot(params = {}) ⇒ Struct
Creates a snapshot of the specified simulation. A snapshot is a file that contains simulation state data at a specific time. The state data saved in a snapshot includes entity data from the State Fabric, the simulation configuration specified in the schema, and the clock tick number. You can use the snapshot to initialize a new simulation. For more information about snapshots, see Snapshots in the SimSpace Weaver User Guide.
You specify a Destination when you create a snapshot. The
Destination is the name of an Amazon S3 bucket and an optional
ObjectKeyPrefix. The ObjectKeyPrefix is usually the name of a
folder in the bucket. SimSpace Weaver creates a snapshot folder
inside the Destination and places the snapshot file there.
The snapshot file is an Amazon S3 object. It has an object key with
the form: object-key-prefix/snapshot/simulation-name-YYMMdd-HHmm-ss.zip, where:
-
YYis the 2-digit year -
MMis the 2-digit month -
ddis the 2-digit day of the month -
HHis the 2-digit hour (24-hour clock) -
mmis the 2-digit minutes -
ssis the 2-digit seconds
85 |
# File 'sig/client.rbs', line 85
def create_snapshot: (
|
#delete_app(params = {}) ⇒ Struct
Deletes the instance of the given custom app.
98 |
# File 'sig/client.rbs', line 98
def delete_app: (
|
#delete_simulation(params = {}) ⇒ Struct
Deletes all SimSpace Weaver resources assigned to the given simulation.
109 |
# File 'sig/client.rbs', line 109
def delete_simulation: (
|
#describe_app(params = {}) ⇒ Types::DescribeAppOutput
Returns the state of the given custom app.
126 |
# File 'sig/client.rbs', line 126
def describe_app: (
|
#describe_simulation(params = {}) ⇒ Types::DescribeSimulationOutput
Returns the current state of the given simulation.
152 |
# File 'sig/client.rbs', line 152
def describe_simulation: (
|
#list_apps(params = {}) ⇒ Types::ListAppsOutput
Lists all custom apps or service apps for the given simulation and domain.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
163 |
# File 'sig/client.rbs', line 163
def list_apps: (
|
#list_simulations(params = {}) ⇒ Types::ListSimulationsOutput
Lists the SimSpace Weaver simulations in the Amazon Web Services account used to make the API call.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
177 |
# File 'sig/client.rbs', line 177
def list_simulations: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Lists all tags on a SimSpace Weaver resource.
188 |
# File 'sig/client.rbs', line 188
def list_tags_for_resource: (
|
#start_app(params = {}) ⇒ Types::StartAppOutput
Starts a custom app with the configuration specified in the simulation schema.
200 |
# File 'sig/client.rbs', line 200
def start_app: (
|
#start_clock(params = {}) ⇒ Struct
Starts the simulation clock.
216 |
# File 'sig/client.rbs', line 216
def start_clock: (
|
#start_simulation(params = {}) ⇒ Types::StartSimulationOutput
Starts a simulation with the given name. You must choose to start your simulation from a schema or from a snapshot. For more information about the schema, see the schema reference in the SimSpace Weaver User Guide. For more information about snapshots, see Snapshots in the SimSpace Weaver User Guide.
228 |
# File 'sig/client.rbs', line 228
def start_simulation: (
|
#stop_app(params = {}) ⇒ Struct
Stops the given custom app and shuts down all of its allocated compute resources.
250 |
# File 'sig/client.rbs', line 250
def stop_app: (
|
#stop_clock(params = {}) ⇒ Struct
Stops the simulation clock.
261 |
# File 'sig/client.rbs', line 261
def stop_clock: (
|
#stop_simulation(params = {}) ⇒ Struct
Stops the given simulation.
You can't restart a simulation after you stop it. If you want to restart a simulation, then you must stop it, delete it, and start a new instance of it.
270 |
# File 'sig/client.rbs', line 270
def stop_simulation: (
|
#tag_resource(params = {}) ⇒ Struct
Adds tags to a SimSpace Weaver resource. For more information about tags, see Tagging Amazon Web Services resources in the Amazon Web Services General Reference.
279 |
# File 'sig/client.rbs', line 279
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes tags from a SimSpace Weaver resource. For more information about tags, see Tagging Amazon Web Services resources in the Amazon Web Services General Reference.
289 |
# File 'sig/client.rbs', line 289
def untag_resource: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1252 1253 1254 |
# File 'lib/aws-sdk-simspaceweaver/client.rb', line 1252 def waiter_names [] end |