Class: Aws::SimSpaceWeaver::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::SimSpaceWeaver::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-simspaceweaver/client.rb
Overview
An API client for SimSpaceWeaver. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::SimSpaceWeaver::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_snapshot(params = {}) ⇒ Struct
Creates a snapshot of the specified simulation.
-
#delete_app(params = {}) ⇒ Struct
Deletes the instance of the given custom app.
-
#delete_simulation(params = {}) ⇒ Struct
Deletes all SimSpace Weaver resources assigned to the given simulation.
-
#describe_app(params = {}) ⇒ Types::DescribeAppOutput
Returns the state of the given custom app.
-
#describe_simulation(params = {}) ⇒ Types::DescribeSimulationOutput
Returns the current state of the given simulation.
-
#list_apps(params = {}) ⇒ Types::ListAppsOutput
Lists all custom apps or service apps for the given simulation and domain.
-
#list_simulations(params = {}) ⇒ Types::ListSimulationsOutput
Lists the SimSpace Weaver simulations in the Amazon Web Services account used to make the API call.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Lists all tags on a SimSpace Weaver resource.
-
#start_app(params = {}) ⇒ Types::StartAppOutput
Starts a custom app with the configuration specified in the simulation schema.
-
#start_clock(params = {}) ⇒ Struct
Starts the simulation clock.
-
#start_simulation(params = {}) ⇒ Types::StartSimulationOutput
Starts a simulation with the given name.
-
#stop_app(params = {}) ⇒ Struct
Stops the given custom app and shuts down all of its allocated compute resources.
-
#stop_clock(params = {}) ⇒ Struct
Stops the simulation clock.
-
#stop_simulation(params = {}) ⇒ Struct
Stops the given simulation.
-
#tag_resource(params = {}) ⇒ Struct
Adds tags to a SimSpace Weaver resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from a SimSpace Weaver resource.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-simspaceweaver/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1259 1260 1261 |
# File 'lib/aws-sdk-simspaceweaver/client.rb', line 1259 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1262 1263 1264 |
# File 'lib/aws-sdk-simspaceweaver/client.rb', line 1262 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1232 1233 1234 1235 1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 1247 1248 |
# File 'lib/aws-sdk-simspaceweaver/client.rb', line 1232 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::SimSpaceWeaver') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-simspaceweaver' context[:gem_version] = '1.47.0' Seahorse::Client::Request.new(handlers, context) end |
#create_snapshot(params = {}) ⇒ Struct
Creates a snapshot of the specified simulation. A snapshot is a file that contains simulation state data at a specific time. The state data saved in a snapshot includes entity data from the State Fabric, the simulation configuration specified in the schema, and the clock tick number. You can use the snapshot to initialize a new simulation. For more information about snapshots, see [Snapshots] in the *SimSpace Weaver User Guide*.
You specify a ‘Destination` when you create a snapshot. The `Destination` is the name of an Amazon S3 bucket and an optional `ObjectKeyPrefix`. The `ObjectKeyPrefix` is usually the name of a folder in the bucket. SimSpace Weaver creates a `snapshot` folder inside the `Destination` and places the snapshot file there.
The snapshot file is an Amazon S3 object. It has an object key with the form: ‘ object-key-prefix/snapshot/simulation-name-YYMMdd-HHmm-ss.zip`, where:
-
‘ YY ` is the 2-digit year
-
‘ MM ` is the 2-digit month
-
‘ dd ` is the 2-digit day of the month
-
‘ HH ` is the 2-digit hour (24-hour clock)
-
‘ mm ` is the 2-digit minutes
-
‘ ss ` is the 2-digit seconds
[1]: docs.aws.amazon.com/simspaceweaver/latest/userguide/working-with_snapshots.html
537 538 539 540 |
# File 'lib/aws-sdk-simspaceweaver/client.rb', line 537 def create_snapshot(params = {}, = {}) req = build_request(:create_snapshot, params) req.send_request() end |
#delete_app(params = {}) ⇒ Struct
Deletes the instance of the given custom app.
567 568 569 570 |
# File 'lib/aws-sdk-simspaceweaver/client.rb', line 567 def delete_app(params = {}, = {}) req = build_request(:delete_app, params) req.send_request() end |
#delete_simulation(params = {}) ⇒ Struct
Deletes all SimSpace Weaver resources assigned to the given simulation.
<note markdown=“1”> Your simulation uses resources in other Amazon Web Services. This API operation doesn’t delete resources in other Amazon Web Services.
</note>
595 596 597 598 |
# File 'lib/aws-sdk-simspaceweaver/client.rb', line 595 def delete_simulation(params = {}, = {}) req = build_request(:delete_simulation, params) req.send_request() end |
#describe_app(params = {}) ⇒ Types::DescribeAppOutput
Returns the state of the given custom app.
649 650 651 652 |
# File 'lib/aws-sdk-simspaceweaver/client.rb', line 649 def describe_app(params = {}, = {}) req = build_request(:describe_app, params) req.send_request() end |
#describe_simulation(params = {}) ⇒ Types::DescribeSimulationOutput
Returns the current state of the given simulation.
713 714 715 716 |
# File 'lib/aws-sdk-simspaceweaver/client.rb', line 713 def describe_simulation(params = {}, = {}) req = build_request(:describe_simulation, params) req.send_request() end |
#list_apps(params = {}) ⇒ Types::ListAppsOutput
Lists all custom apps or service apps for the given simulation and domain.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
769 770 771 772 |
# File 'lib/aws-sdk-simspaceweaver/client.rb', line 769 def list_apps(params = {}, = {}) req = build_request(:list_apps, params) req.send_request() end |
#list_simulations(params = {}) ⇒ Types::ListSimulationsOutput
Lists the SimSpace Weaver simulations in the Amazon Web Services account used to make the API call.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
817 818 819 820 |
# File 'lib/aws-sdk-simspaceweaver/client.rb', line 817 def list_simulations(params = {}, = {}) req = build_request(:list_simulations, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Lists all tags on a SimSpace Weaver resource.
852 853 854 855 |
# File 'lib/aws-sdk-simspaceweaver/client.rb', line 852 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#start_app(params = {}) ⇒ Types::StartAppOutput
Starts a custom app with the configuration specified in the simulation schema.
914 915 916 917 |
# File 'lib/aws-sdk-simspaceweaver/client.rb', line 914 def start_app(params = {}, = {}) req = build_request(:start_app, params) req.send_request() end |
#start_clock(params = {}) ⇒ Struct
Starts the simulation clock.
936 937 938 939 |
# File 'lib/aws-sdk-simspaceweaver/client.rb', line 936 def start_clock(params = {}, = {}) req = build_request(:start_clock, params) req.send_request() end |
#start_simulation(params = {}) ⇒ Types::StartSimulationOutput
Starts a simulation with the given name. You must choose to start your simulation from a schema or from a snapshot. For more information about the schema, see the [schema reference] in the *SimSpace Weaver User Guide*. For more information about snapshots, see
- Snapshots][2
-
in the *SimSpace Weaver User Guide*.
[1]: docs.aws.amazon.com/simspaceweaver/latest/userguide/schema-reference.html [2]: docs.aws.amazon.com/simspaceweaver/latest/userguide/working-with_snapshots.html
1066 1067 1068 1069 |
# File 'lib/aws-sdk-simspaceweaver/client.rb', line 1066 def start_simulation(params = {}, = {}) req = build_request(:start_simulation, params) req.send_request() end |
#stop_app(params = {}) ⇒ Struct
Stops the given custom app and shuts down all of its allocated compute resources.
1097 1098 1099 1100 |
# File 'lib/aws-sdk-simspaceweaver/client.rb', line 1097 def stop_app(params = {}, = {}) req = build_request(:stop_app, params) req.send_request() end |
#stop_clock(params = {}) ⇒ Struct
Stops the simulation clock.
1119 1120 1121 1122 |
# File 'lib/aws-sdk-simspaceweaver/client.rb', line 1119 def stop_clock(params = {}, = {}) req = build_request(:stop_clock, params) req.send_request() end |
#stop_simulation(params = {}) ⇒ Struct
Stops the given simulation.
You can’t restart a simulation after you stop it. If you want to restart a simulation, then you must stop it, delete it, and start a new instance of it.
1145 1146 1147 1148 |
# File 'lib/aws-sdk-simspaceweaver/client.rb', line 1145 def stop_simulation(params = {}, = {}) req = build_request(:stop_simulation, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds tags to a SimSpace Weaver resource. For more information about tags, see [Tagging Amazon Web Services resources] in the *Amazon Web Services General Reference*.
1185 1186 1187 1188 |
# File 'lib/aws-sdk-simspaceweaver/client.rb', line 1185 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes tags from a SimSpace Weaver resource. For more information about tags, see [Tagging Amazon Web Services resources] in the *Amazon Web Services General Reference*.
1223 1224 1225 1226 |
# File 'lib/aws-sdk-simspaceweaver/client.rb', line 1223 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1252 1253 1254 |
# File 'lib/aws-sdk-simspaceweaver/client.rb', line 1252 def waiter_names [] end |